@@ -1,13 +1,23 @@
-package Test::DistManifest;
-BEGIN {
-  $Test::DistManifest::VERSION = '1.011';
-}
+package Test::DistManifest; # git description: v1.012-46-gd7db7c1
 # ABSTRACT: Author test that validates a package MANIFEST
-
+# KEYWORDS: test distribution manifest files upload contents author
+our $VERSION = '1.013';
 use strict;
 use warnings;
 use Carp ();
+use ExtUtils::Manifest;
 
+#pod =head1 EXPORTS
+#pod
+#pod By default, this module exports the following functions:
+#pod
+#pod =over
+#pod
+#pod =item * manifest_ok
+#pod
+#pod =back
+#pod
+#pod =cut
 
 # File management commands
 use Cwd ();
@@ -15,7 +25,7 @@ use File::Spec; # Portability
 use File::Spec::Unix; # To get UNIX-style paths
 use File::Find (); # Traverse the filesystem tree
 
-use Module::Manifest;
+use Module::Manifest 0.07;
 use Test::Builder;
 
 my $test = Test::Builder->new;
@@ -54,6 +64,104 @@ sub import {
   return;
 }
 
+#pod =head1 DESCRIPTION
+#pod
+#pod This module provides a simple method of testing that a MANIFEST matches the
+#pod distribution.
+#pod
+#pod It tests three things:
+#pod
+#pod =for stopwords unsatisfiable
+#pod
+#pod =over
+#pod
+#pod =item 1
+#pod
+#pod Everything in B<MANIFEST> exists
+#pod
+#pod =item 2
+#pod
+#pod Everything in the package is listed in B<MANIFEST>, or subsequently matches
+#pod a regular expression mask in B<MANIFEST.SKIP>
+#pod
+#pod =item 3
+#pod
+#pod Nothing exists in B<MANIFEST> that also matches a mask in B<MANIFEST.SKIP>,
+#pod so as to avoid an unsatisfiable dependency conditions
+#pod
+#pod =back
+#pod
+#pod If there is no B<MANIFEST.SKIP> included in your distribution, this module
+#pod will replicate the toolchain behaviour of using the default system-wide
+#pod MANIFEST.SKIP file. To view the contents of this file, use the command:
+#pod
+#pod   $ perldoc -m ExtUtils::MANIFEST.SKIP
+#pod
+#pod =head1 SYNOPSIS
+#pod
+#pod This is the common idiom for author test modules like this, but see
+#pod the full example in examples/checkmanifest.t and, more importantly,
+#pod Adam Kennedy's article: L<http://use.perl.org/use.perl.org/_Alias/journal/38822.html>
+#pod
+#pod   use Test::More;
+#pod   eval 'use Test::DistManifest';
+#pod   if ($@) {
+#pod     plan skip_all => 'Test::DistManifest required to test MANIFEST';
+#pod   }
+#pod
+#pod   manifest_ok('MANIFEST', 'MANIFEST.SKIP'); # Default options
+#pod
+#pod   manifest_ok(); # Functionally equivalent to above
+#pod
+#pod =head1 FUNCTIONS
+#pod
+#pod =head2 manifest_ok
+#pod
+#pod   manifest_ok( $manifest, $skipfile )
+#pod
+#pod This subroutine checks the manifest list contained in C<$manifest> by using
+#pod C<Module::Manifest> to determine the list of files and then checking for the
+#pod existence of all such files. Then, it checks if there are any files in the
+#pod distribution that were not specified in the C<$manifest> file but do not match
+#pod any regular expressions provided in the C<$skipfile> exclusion file.
+#pod
+#pod If your MANIFEST file is generated by a module installation toolchain system
+#pod such as L<ExtUtils::MakeMaker>, L<Module::Build> or L<Module::Install>, then
+#pod you shouldn't have any problems with these files. It's just a helpful test
+#pod to remind you to update these files, using:
+#pod
+#pod   $ make manifest # For ExtUtils::MakeMaker
+#pod   $ ./Build manifest # For Module::Build
+#pod
+#pod =head1 NON-FATAL ERRORS
+#pod
+#pod By default, errors in the B<MANIFEST> or B<MANIFEST.SKIP> files are treated
+#pod as fatal, which really is the purpose of using C<Test::DistManifest> as part
+#pod of your author test suite.
+#pod
+#pod In some cases this is not desirable behaviour, such as with the Debian Perl
+#pod Group, which runs all tests - including author tests - as part of its module
+#pod packaging process. This wreaks havoc because Debian adds its control files
+#pod in C<debian/> downstream, and that directory or its files are generally not
+#pod in B<MANIFEST.SKIP>.
+#pod
+#pod By setting the environment variable B<MANIFEST_WARN_ONLY> to a true value,
+#pod errors will be non-fatal - they show up as diagnostic messages only, but all
+#pod tests pass from the perspective of C<Test::Harness>.
+#pod
+#pod This can be used in a test script as:
+#pod
+#pod   $ENV{MANIFEST_WARN_ONLY} = 1;
+#pod
+#pod or from other shell scripts as:
+#pod
+#pod   export MANIFEST_WARN_ONLY=1
+#pod
+#pod Note that parsing errors in B<MANIFEST> and circular dependencies will
+#pod always be considered fatal. The author is not aware of any cases where
+#pod other behaviour would be useful.
+#pod
+#pod =cut
 
 sub manifest_ok {
   my $warn_only = $ENV{MANIFEST_WARN_ONLY} || 0;
@@ -83,49 +191,12 @@ sub manifest_ok {
   if ($@) {
     $test->diag('Unable to parse MANIFEST.SKIP file:');
     $test->diag($!);
-    $test->diag('Using default skip data from ExtUtils::Manifest 1.58');
-    $manifest->parse( skip => [
-      # Version control files
-      '\bRCS\b',
-      '\bCVS\b',
-      '\bSCCS\b',
-      ',v$',
-      '\B\.svn\b',
-      '\B\.git\b',
-      '\B\.gitignore\b',
-      '\b_darcs\b',
-      '\B\.cvsignore$',
-      # Build remnants
-      '\bMANIFEST\.bak',
-      '\bMakefile$',
-      '\bblib/',
-      '\bMakeMaker-\d',
-      '\bpm_to_blib\.ts$',
-      '\bpm_to_blib$',
-      '\bblibdirs\.ts$',
-      '\bBuild$',
-      '\b_build/',
-      '\bBuild.bat$',
-      '\bBuild.COM$',
-      '\bBUILD.COM$',
-      '\bbuild.com$',
-      '^MYMETA\.',
-      # Temporary and backup files
-      '~$',
-      '\.old$',
-      '\#$',
-      '\b\.#',
-      '\.bak$',
-      '\.tmp$',
-      '\.#',
-      '\.rej$',
-      # Mac OSX metadata
-      '\B\.DS_Store',
-      '\B\._',
-      # Devel::Cover files
-      '\bcover_db\b',
-      '\bcovered\b',
-    ]);
+    $test->diag('Using default skip data from ExtUtils::Manifest ' . ExtUtils::Manifest->VERSION);
+
+    open my $fh, '<', $ExtUtils::Manifest::DEFAULT_MSKIP
+        or die "Cannot open $ExtUtils::Manifest::DEFAULT_MSKIP: $!";
+    chomp(my @manifest_content = <$fh>);
+    $manifest->parse( skip => \@manifest_content );
   }
 
   my @files;
@@ -220,27 +291,140 @@ sub manifest_ok {
   return;
 }
 
+#pod =head1 GUTS
+#pod
+#pod This module internally plans four tests:
+#pod
+#pod =over
+#pod
+#pod =item 1
+#pod
+#pod B<MANIFEST> can be parsed by C<Module::Manifest>
+#pod
+#pod =item 2
+#pod
+#pod Check which files exist in the distribution directory that do not match an
+#pod existing regular expression in B<MANIFEST.SKIP> and not listed in the
+#pod B<MANIFEST> file. These files should either be excluded from the test by
+#pod addition of a mask in MANIFEST.SKIP (in the case of temporary development
+#pod or test files) or should be included in the MANIFEST.
+#pod
+#pod =item 3
+#pod
+#pod Check which files are specified in B<MANIFEST> but do not exist on the disk.
+#pod This usually occurs when one deletes a test or similar script from the
+#pod distribution, or accidentally moves it.
+#pod
+#pod =item 4
+#pod
+#pod Check which files are specified in both B<MANIFEST> and B<MANIFEST.SKIP>.
+#pod This is clearly an unsatisfiable condition, since the file in question
+#pod cannot be expected to be included while also simultaneously ignored.
+#pod
+#pod =back
+#pod
+#pod If you want to run tests on multiple different MANIFEST files, you can
+#pod simply pass 'no_plan' to the import function, like so:
+#pod
+#pod   use Test::DistManifest 'no_plan';
+#pod
+#pod   # Multiple tests work properly now
+#pod   manifest_ok('MANIFEST', 'MANIFEST.SKIP');
+#pod   manifest_ok();
+#pod   manifest_ok('MANIFEST.OTHER', 'MANIFEST.SKIP');
+#pod
+#pod I doubt this will be useful to users of this module. However, this is used
+#pod internally for testing and it might be helpful to you. You can also plan
+#pod more tests, but keep in mind that the idea of "3 internal tests" may change
+#pod in the future.
+#pod
+#pod Example code:
+#pod
+#pod   use Test::DistManifest tests => 5;
+#pod   manifest_ok(); # 4 tests
+#pod   ok(1, 'is 1 true?');
+#pod
+#pod =head1 ACKNOWLEDGEMENTS
+#pod
+#pod =over
+#pod
+#pod =item *
+#pod
+#pod Thanks to Adam Kennedy for developing L<Module::Manifest>, which provides
+#pod much of the core functionality for these tests.
+#pod
+#pod =item *
+#pod
+#pod Thanks to Apocalypse E<lt>apocal@cpan.orgE<gt>, for helping me track down
+#pod an obscure bug caused by circular dependencies: when files are expected by
+#pod MANIFEST but explicitly skipped by MANIFEST.SKIP.
+#pod
+#pod =back
+#pod
+#pod =head1 SEE ALSO
+#pod
+#pod =over
+#pod
+#pod =item *
+#pod L<Test::CheckManifest>, a module providing similar functionality
+#pod
+#pod =item *
+#pod L<Module::Manifest>
+#pod
+#pod =item *
+#pod L<Dist::Zilla::Plugin::Test::DistManifest>
+#pod
+#pod =item *
+#pod L<Test::Manifest>
+#pod
+#pod =back
+#pod
+#pod =head1 CAVEATS
+#pod
+#pod =over
+#pod
+#pod =item *
+#pod
+#pod There is currently no way to test a MANIFEST/MANIFEST.SKIP without having the
+#pod files actually exist on disk. I am planning for this to change in the future.
+#pod
+#pod =item *
+#pod
+#pod This module has not been tested very thoroughly with Unicode.
+#pod
+#pod =item *
+#pod
+#pod This module does not produce any useful diagnostic messages in terms of how
+#pod to correct the situation. Hopefully this will be obvious for anybody using
+#pod the module; the emphasis should be on generating helpful error messages.
+#pod
+#pod =back
+#pod
+#pod =cut
 
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Test::DistManifest - Author test that validates a package MANIFEST
 
 =head1 VERSION
 
-version 1.011
+version 1.013
 
 =head1 SYNOPSIS
 
-  use Test::More;
+This is the common idiom for author test modules like this, but see
+the full example in examples/checkmanifest.t and, more importantly,
+Adam Kennedy's article: L<http://use.perl.org/use.perl.org/_Alias/journal/38822.html>
 
-  # This is the common idiom for author test modules like this, but see
-  # the full example in examples/checkmanifest.t and, more importantly,
-  # Adam Kennedy's article: http://use.perl.org/~Alias/journal/38822
+  use Test::More;
   eval 'use Test::DistManifest';
   if ($@) {
     plan skip_all => 'Test::DistManifest required to test MANIFEST';
@@ -257,6 +441,18 @@ distribution.
 
 It tests three things:
 
+=head1 EXPORTS
+
+By default, this module exports the following functions:
+
+=over
+
+=item * manifest_ok
+
+=back
+
+=for stopwords unsatisfiable
+
 =over
 
 =item 1
@@ -281,16 +477,6 @@ MANIFEST.SKIP file. To view the contents of this file, use the command:
 
   $ perldoc -m ExtUtils::MANIFEST.SKIP
 
-=head1 EXPORTS
-
-By default, this module exports the following functions:
-
-=over
-
-=item * manifest_ok
-
-=back
-
 =head1 FUNCTIONS
 
 =head2 manifest_ok
@@ -311,7 +497,7 @@ to remind you to update these files, using:
   $ make manifest # For ExtUtils::MakeMaker
   $ ./Build manifest # For Module::Build
 
-=head2 Non-Fatal Errors
+=head1 NON-FATAL ERRORS
 
 By default, errors in the B<MANIFEST> or B<MANIFEST.SKIP> files are treated
 as fatal, which really is the purpose of using C<Test::DistManifest> as part
@@ -341,7 +527,7 @@ other behaviour would be useful.
 
 =head1 GUTS
 
-This module internally plans 4 tests:
+This module internally plans four tests:
 
 =over
 
@@ -405,14 +591,28 @@ much of the core functionality for these tests.
 
 Thanks to Apocalypse E<lt>apocal@cpan.orgE<gt>, for helping me track down
 an obscure bug caused by circular dependencies: when files are expected by
-MANIFEST but explictly skipped by MANIFEST.SKIP.
+MANIFEST but explicitly skipped by MANIFEST.SKIP.
 
 =back
 
 =head1 SEE ALSO
 
+=over
+
+=item *
 L<Test::CheckManifest>, a module providing similar functionality
 
+=item *
+L<Module::Manifest>
+
+=item *
+L<Dist::Zilla::Plugin::Test::DistManifest>
+
+=item *
+L<Test::Manifest>
+
+=back
+
 =head1 CAVEATS
 
 =over
@@ -434,25 +634,21 @@ the module; the emphasis should be on generating helpful error messages.
 
 =back
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-http://rt.cpan.org/NoAuth/Bugs.html?Dist=Test-DistManifest
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 AUTHOR
 
 Jonathan Yu <jawnsy@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Jonathan Yu <jawnsy@cpan.org>.
+This software is copyright (c) 2008 by Jonathan Yu <jawnsy@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=cut
+=head1 CONTRIBUTOR
 
+=for stopwords Karen Etheridge
+
+Karen Etheridge <ether@cpan.org>
+
+=cut
